@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -28,7 +28,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -108,8 +108,8 @@ from .extra import get_a, post_a, put_a, delete_a, patch_a, get_w, post_w, put_w
 from .geo import GeoResolver
 from .git import Git
 from .http import file_g, get_f, get, post, put, delete, HTTPResponse
-from .log import MemoryHandler, BaseFormatter, ThreadFormatter, DummyLogger, rotating_handler, smtp_handler,\
-    in_signature
+from .log import MemoryHandler, BaseFormatter, ThreadFormatter, DummyLogger, reload_format, rotating_handler,\
+    smtp_handler, in_signature
 from .meta import Ordered, Indexed
 from .mock import MockObject, MockResponse, MockApp
 from .model import Model, LocalModel, Field, link, operation, view, field, type_d, is_unset
@@ -125,7 +125,7 @@ from .serialize import serialize_csv, serialize_ics, build_encoder
 from .session import Session, MockSession, MemorySession, FileSession, RedisSession, ClientSession
 from .settings import DEBUG, USERNAME, PASSWORD
 from .smtp import message, message_base, message_netius, smtp_engine, multipart, plain,\
-    html, header
+    html, application, header
 from .storage import StorageEngine, BaseEngine, FsEngine
 from .structures import OrderedDict, LazyDict, LazyValue, GeneratorFile, lazy_dict, lazy
 from .typesf import AbstractType, Type, File, Files, ImageFile, ImageFiles, image, images, Reference,\
@@ -134,11 +134,11 @@ from .util import is_iterable, is_mobile, is_tablet, is_browser, is_bot, browser
     email_name, email_base, date_to_timestamp, obfuscate, import_pip, ensure_pip, install_pip, install_pip_s,\
     request_json, get_context, get_object, resolve_alias, page_types, find_types, norm_object, set_object, leafs,\
     gather_errors, gen_token, html_to_text, camel_to_underscore, camel_to_readable, underscore_to_readable, quote,\
-    unquote, unescape, split_unescape, call_safe, base_name, base_name_m, is_content_type, parse_content_type, parse_cookie,\
-    parse_multipart, decode_params, load_form, check_login, check_token, check_tokens, ensure_login, get_tokens_m,\
-    to_tokens_m, dict_merge, deprecated, cached, private, ensure, delayed, route, error_handler, exception_handler,\
-    before_request, after_request, is_detached, sanitize, verify, verify_equal, verify_not_equal, verify_many, execute,\
-    ctx_locale, ctx_request, FileTuple, BaseThread, JSONEncoder
+    unquote, escape, unescape, split_unescape, call_safe, base_name, base_name_m, is_content_type, parse_content_type,\
+    parse_cookie, parse_multipart, decode_params, load_form, check_login, check_user, check_token, check_tokens,\
+    ensure_login, get_tokens_m, to_tokens_m, dict_merge, deprecated, cached, private, ensure, delayed, route, error_handler,\
+    exception_handler, before_request, after_request, is_detached, sanitize, verify, verify_equal, verify_not_equal,\
+    verify_many, execute, ctx_locale, ctx_request, FileTuple, BaseThread, JSONEncoder
 from .validation import validate, validate_b, validate_e, safe, eq, gt, gte, lt, lte, not_null, not_empty, not_false,\
     is_in, is_upper, is_lower, is_simple, is_email, is_url, is_regex, field_eq, field_gt, field_gte, field_lt,\
     field_lte, string_gt, string_lt, string_eq, equals, not_past, not_duplicate, all_different, no_self
