@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -166,7 +166,7 @@ class QueueManager(AsyncManager):
             # gracefully (prints exception to the logger)
             method, args, kwargs = item
             try: method(*args, **kwargs)
-            except BaseException as exception:
+            except Exception as exception:
                 self.owner.log_error(
                     exception,
                     message = "Problem handling async item: %s"
@@ -223,14 +223,20 @@ def to_coroutine(callable, *args, **kwargs):
     of the coroutine execution.
     """
 
-    # tries to retrieve both the future and a callback from
-    # the provided key based arguments in case thre's no future
-    # a new one is created for the current context as for the
-    # callback an unset one is used for invalid situations
+    # tries to retrieve both the safe (flag), future and callback
+    # from the provided key based arguments in case there's no
+    # future a new one is created for the current context as for
+    # the callback an unset one is used for invalid situations
+    safe = kwargs.pop("safe", True)
     future = kwargs.pop("future", None) or build_future()
     callback = kwargs.get("callback", None)
 
     def callback_wrap(result, *args, **kwargs):
+        # in case the safe flag is set and the future is
+        # already done there's nothing remaining to be done
+        # returns immediately the control flow
+        if safe and future.done(): return
+
         # sets the final result in the associated future
         # this should contain the contents coming from
         # the callback operation (payload)
