@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,13 +31,14 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
 import pickle
+import traceback
 import threading
 
 from . import config
@@ -68,6 +69,9 @@ class Bus(component.Component):
 
 class MemoryBus(Bus):
 
+    def __init__(self, name = "memory", owner = None, *args, **kwargs):
+        Bus.__init__(self, name = name, owner = owner, *args, **kwargs)
+
     def bind(self, name, method):
         methods = self._events.get(name, [])
         methods.append(method)
@@ -112,6 +116,10 @@ class RedisBus(Bus):
     """ The name of the global channel to which all of the agents
     should be subscribed, for global communication """
 
+    def __init__(self, name = "redis", owner = None, *args, **kwargs):
+        Bus.__init__(self, name = name, owner = owner, *args, **kwargs)
+        self._delay = kwargs.pop("delay", True)
+
     def bind(self, name, method):
         methods = self._events.get(name, [])
         methods.append(method)
@@ -128,10 +136,12 @@ class RedisBus(Bus):
 
     def trigger(self, name, *args, **kwargs):
         channel = self._to_channel(name)
-        data = self._serializer.dumps(dict(
-            args = args,
-            kwargs = kwargs
-        ))
+        data = self._serializer.dumps(
+            dict(
+                args = args,
+                kwargs = kwargs
+            )
+        )
         self._redis.publish(channel, data)
 
     def _load(self, *args, **kwargs):
@@ -180,29 +190,36 @@ class RedisBus(Bus):
 
     def _loop(self, safe = True):
         for item in self._pubsub.listen():
-            channel = item.get("channel", None)
-            channel = legacy.str(channel)
-            type = item.get("type", None)
-            data = item.get("data", None)
-            if not type in ("message",): continue
-            if ":" in channel: _prefix, name = channel.split(":", 1)
-            else: name = channel
-            data = self._serializer.loads(data)
-            methods = self._events.get(name, [])
-            for method in methods:
-                if safe:
-                    self.owner.schedule(
-                        method,
-                        args = data["args"],
-                        kwargs = data["kwargs"],
-                        timeout = -1,
-                        safe = True
-                    )
-                else:
-                    method(
-                        *data["args"],
-                        **data["kwargs"]
-                    )
+            try:
+                if not self.loaded: break
+                self._tick(item, safe = safe)
+            except Exception as exception:
+                self.logger.critical("Unhandled redis loop exception raised")
+                self.logger.error(exception)
+                lines = traceback.format_exc().splitlines()
+                for line in lines: self.logger.warning(line)
+
+    def _tick(self, item, safe = True):
+        channel = item.get("channel", None)
+        channel = legacy.str(channel)
+        type = item.get("type", None)
+        data = item.get("data", None)
+        if not type in ("message",): return
+        if ":" in channel: _prefix, name = channel.split(":", 1)
+        else: name = channel
+        data = self._serializer.loads(data)
+        methods = self._events.get(name, []) if self._events else []
+        for method in methods:
+            if safe:
+                self.owner.schedule(
+                    method,
+                    args = data["args"],
+                    kwargs = data["kwargs"],
+                    timeout = -1,
+                    safe = True
+                )
+            else:
+                method(*data["args"], **data["kwargs"])
 
     def _to_channel(self, name):
         return self._name + ":" + name
