@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -98,7 +98,7 @@ class DataAdapter(object):
         try:
             token += struct.pack(">i", self._inc)[1:4]
             self._inc = (self._inc + 1) % 0xffffff
-        except:
+        except Exception:
             self._inc_lock.release()
         token_s = binascii.hexlify(token)
         token_s = legacy.str(token_s)
