@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -146,6 +146,11 @@ class ValidationError(OperationalError):
         if not extended: return message
         errors_s = self.errors_s()
         if not errors_s: return message
+        if self.model:
+            message += " for model '%s' with id '%s'" % (
+                self.model.__class__._name(),
+                self.model._id if hasattr(self.model, "_id") else "unset"
+            )
         errors_s = errors_s.encode("utf-8")
         message += " (" + errors_s + ")"
         return message
@@ -156,6 +161,11 @@ class ValidationError(OperationalError):
         if not extended: return message
         errors_s = self.errors_s()
         if not errors_s: return message
+        if self.model:
+            message += " for model '%s' with id '%s'" % (
+                self.model.__class__._name(),
+                self.model._id if hasattr(self.model, "_id") else "unset"
+            )
         message += " (" + errors_s + ")"
         return message
 
@@ -284,7 +294,7 @@ class HTTPError(BaseInternalError):
         if extended:
             data = self.read(error = error)
             try: data = data.decode("utf-8")
-            except: data = legacy.str(data)
+            except Exception: data = legacy.str(data)
             if data: message = message + "\n" + data if message else data
         BaseInternalError.__init__(self, message)
         self.code = code
@@ -301,7 +311,7 @@ class HTTPError(BaseInternalError):
         data = self.read(error = error)
         if legacy.is_bytes(data): data = data.decode("utf-8")
         try: data_j = json.loads(data)
-        except: data_j = None
+        except Exception: data_j = None
         return data_j
 
 class APIError(BaseInternalError):
