@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -145,7 +145,7 @@ class ExecutionThread(threading.Thread):
                 # execution fails (must be done to log the error) then
                 # sets the error flag with the exception variable
                 try: callable(*args, **kwargs)
-                except BaseException as exception:
+                except Exception as exception:
                     error = exception
                     lines = traceback.format_exc().splitlines()
                     logger = common.base().get_logger()
