@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -165,7 +165,7 @@ class ExportManager(object):
             # new value is generated using the pre-defined strategy
             if "_id" in entity:
                 try: entity["_id"] = self.adapter.object_id(entity["_id"])
-                except: entity["_id"] = entity["_id"]
+                except Exception: entity["_id"] = entity["_id"]
             else: entity["_id"] = self.adapter.object_id()
 
             # retrieves the key value for the current entity to
@@ -212,7 +212,7 @@ class ExportManager(object):
             # new value is generated using the pre-defined strategy
             if "_id" in entity:
                 try: entity["_id"] = self.adapter.object_id(entity["_id"])
-                except: entity["_id"] = entity["_id"]
+                except Exception: entity["_id"] = entity["_id"]
             else: entity["_id"] = self.adapter.object_id()
 
             # retrieves the key value for the current entity to
