@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -524,7 +524,7 @@ class Request(object):
         if mime_type == "application/json":
             data = self.data.decode("utf-8") if self.data else None
             try: self.data_j = json.loads(data) if data else None
-            except: pass
+            except Exception: pass
         elif mime_type == "application/x-www-form-urlencoded":
             data = legacy.str(self.data) if self.data else None
             post = legacy.parse_qs(
@@ -705,7 +705,7 @@ class Request(object):
         # provided sid (session id) in case there's an exception
         # defaults to unset session so that a new one gets created
         try: session = self.session_c.get_s(sid, request = self)
-        except: session = None
+        except Exception: session = None
 
         # in case no valid session exists a new one must be created
         # so that the user may be able to interact with the system
