@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -43,6 +43,7 @@ import email.header
 
 import email.mime.text
 import email.mime.multipart
+import email.mime.application
 
 from . import config
 from . import legacy
@@ -121,7 +122,7 @@ def message_netius(
 
 def smtp_engine():
     try: imp.find_module("netius")
-    except: return "base"
+    except ImportError: return "base"
     return "netius"
 
 def multipart():
@@ -133,6 +134,9 @@ def plain(contents, encoding = "utf-8"):
 def html(contents, encoding = "utf-8"):
     return email.mime.text.MIMEText(contents, "html", encoding)
 
+def application(contents, name = "unnamed"):
+    return email.mime.application.MIMEApplication(contents, Name = name)
+
 def header(value, encoding = "utf-8", encode = True):
     header = email.header.Header(value, encoding)
     if encode: header = header.encode()
