@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -128,8 +128,9 @@ class QueuingTest(unittest.TestCase):
         self.assertEqual(_identifier_3, identifier_3)
 
     def test_amqp(self):
-        try: queue = appier.AMQPQueue()
-        except:
+        try:
+            queue = appier.AMQPQueue()
+        except Exception:
             if not hasattr(self, "skipTest"): return
             self.skipTest("No AMQP server present")
 
