@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -592,6 +592,13 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello World")
 
+    def test_escape(self):
+        result = appier.escape("foo,bar", ",", escape = "$")
+        self.assertEqual(result, "foo$,bar")
+
+        result = appier.escape("foo$,bar", ",", escape = "$")
+        self.assertEqual(result, "foo$$$,bar")
+
     def test_unescape(self):
         result = appier.unescape("foo$,bar", escape = "$")
         self.assertEqual(result, "foo,bar")
