@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -54,8 +54,10 @@ import threading
 import mimetypes
 import contextlib
 import subprocess
+import multiprocessing
 
 from . import smtp
+from . import config
 from . import legacy
 from . import common
 from . import defines
@@ -117,6 +119,7 @@ ALIAS = {
     "filter_def" : "find_d",
     "filter_string" : "find_s",
     "filter_name" : "find_n",
+    "filter_operator" : "find_o",
     "insensitive" : "find_i",
     "order" : "sort",
     "offset" : "skip",
@@ -134,6 +137,7 @@ FIND_TYPES = dict(
     find_i = bool,
     find_t = legacy.UNICODE,
     find_n = legacy.UNICODE,
+    find_o = legacy.UNICODE,
     sort = to_sort,
     meta = bool,
     fields = list
@@ -374,7 +378,7 @@ def email_base(base):
 def date_to_timestamp(value, format = "%d/%m/%Y"):
     if not value: return None
     try: value = datetime.datetime.strptime(value, format)
-    except: return None
+    except Exception: return None
     value = value.utctimetuple()
     return calendar.timegm(value)
 
@@ -386,37 +390,46 @@ def obfuscate(value, display_l = 3, token = "*"):
 
 def import_pip(name, package = None, default = None):
     package = package or name
-    try: module = __import__(name)
-    except:
+    try:
+        module = __import__(name)
+    except ImportError:
         try: module = install_pip_s(package)
-        except: return default
+        except Exception: return default
         try: module = __import__(name)
-        except: return default
+        except ImportError: return default
     return module
 
 def ensure_pip(name, package = None, delayed = False):
     package = package or name
     try:
         __import__(name)
-    except:
+    except ImportError:
         install_pip_s(package, delayed = delayed)
 
-def install_pip(package, delayed = False, user = False):
+def install_pip(package, delayed = False, isolated = True, user = None):
     import pip #@UnusedImport
     try: import pip._internal
-    except: pip._internal = None
+    except ImportError: pip._internal = None
+    user = config.conf("PIP_USER", False, cast = bool)
     args = ["install", package]
     if hasattr(pip._internal, "main"): pip_main = pip._internal.main
     else: pip_main = pip.main #@UndefinedVariable
     if user: args.insert(1, "--user")
     if delayed:
-        import multiprocessing
         process = multiprocessing.Process(
             target = pip_main,
             args = (args,)
         )
         process.start()
         result = 0
+    elif isolated:
+        process = multiprocessing.Process(
+            target = pip_main,
+            args = (args,)
+        )
+        process.start()
+        process.join()
+        result = process.exitcode
     else:
         result = pip_main(args)
     if result == 0: return
@@ -444,7 +457,8 @@ def request_json(request = None, encoding = "utf-8"):
         is_bytes = legacy.is_bytes(data)
         if is_bytes: data = data.decode(encoding)
         data_j = json.loads(data)
-    except: data_j = {}
+    except Exception:
+        data_j = {}
     request.properties["_data_j"] = data_j
 
     # returns the json data object to the caller method so that it
@@ -741,8 +755,8 @@ def gen_token(limit = None, hash = hashlib.sha256):
     """
     Generates a random cryptographic ready token according
     to the framework specification, this is generated using
-    a truly random uuid based seed and hashed using the
-    provided hash digest strategy (sha256 by default).
+    a truly random UUID based seed and hashed using the
+    provided hash digest strategy (SHA256 by default).
 
     The resulting value is returned as an hexadecimal based
     string according to the standard.
@@ -789,7 +803,7 @@ def html_to_text(data):
     data = data.replace("&middot;", "-")
 
     result = re.findall(defines.BODY_REGEX, data)
-    data = result[0]
+    data = result[0] if result else ""
 
     data = defines.TAG_REGEX.sub("", data)
 
@@ -890,7 +904,7 @@ def quote(value, *args, **kwargs):
     """
     Quotes the passed value according to the defined
     standard for URL escaping, the value is first encoded
-    into the expected utf-8 encoding as defined by standard.
+    into the expected UTF-8 encoding as defined by standard.
 
     This method should be used instead of a direct call to
     the equivalent call in the URL library.
@@ -912,7 +926,7 @@ def unquote(value, *args, **kwargs):
     Unquotes the provided value according to the URL scheme
     the resulting value should be an unicode string representing
     the same value, the intermediary string value from the decoding
-    should be an utf-8 based value.
+    should be an UTF-8 based value.
 
     This method should be used instead of a direct call to
     the equivalent call in the URL library.
@@ -930,6 +944,25 @@ def unquote(value, *args, **kwargs):
     if is_bytes: value = value.decode("utf-8")
     return value
 
+def escape(value, char, escape = "\\"):
+    """
+    Escapes the provided string value according to the requested
+    target character and escape value. Meaning that all the characters
+    are going to be replaced by the escape plus character sequence.
+
+    :type value: String
+    :param value: The string that is going to have the target characters
+    escaped according to the escape character.
+    :type char: String
+    :param char: The character that is going to be "target" of escaping.
+    :type escape: String
+    :param escape: The character to be used for escaping (normally`\`).
+    :rtype: String
+    :return: The final string with the target character properly escaped.
+    """
+
+    return value.replace(escape, escape + escape).replace(char, escape + char)
+
 def unescape(value, escape = "\\"):
     """
     Unescapes the provided string value using the provided escape
@@ -963,7 +996,7 @@ def split_unescape(value, delimiter = " ", max = -1, escape = "\\", unescape = T
     provided escape character.
 
     This is considered to be a very expensive operation when compared
-    to the simples split operation and so it should be used carefully.
+    to the simple split operation and so it should be used carefully.
 
     :type value: String
     :param value: The string value that is going to be split around
@@ -1360,14 +1393,14 @@ def decode_params(params):
     """
     Decodes the complete set of parameters defined in the
     provided map so that all of keys and values are created
-    as unicode strings instead of utf-8 based strings.
+    as unicode strings instead of UTF-8 based strings.
 
     This method's execution is mandatory on the retrieval of
     the parameters from the sent data.
 
     :type params: Dictionary
     :param params: The map containing the encoded set of values
-    that are going to be decoded from the utf-8 form.
+    that are going to be decoded from the UTF-8 form.
     :rtype: Dictionary
     :return: The decoded map meaning that all the keys and values
     are in the unicode form instead of the string form.
@@ -1448,13 +1481,28 @@ def check_login(self, token = None, request = None):
     # in case the username value is set in session and there's
     # no token to be validated returns valid and in case the checking
     # of the complete set of tokens is valid also returns valid
-    if "username" in request.session and not token: return True
+    if check_user(self, request = request) and not token: return True
     if check_tokens(self, tokens, request = request): return True
 
     # returns the default value as invalid because if all the
     # validation procedures have failed the check is invalid
     return False
 
+def check_user(self, request = None):
+    # tries to retrieve the reference to the current request
+    # either from the provided arguments or from the current context
+    request = request or (self.request if self else None)
+
+    # runs the multiple verification strategies available an
+    # in case at least one of them succeeds the user is considered
+    # to be currently authenticated
+    if request and "username" in request.session: return True
+    if request and hasattr(request, "tokens_p"): return True
+
+    # by default the user is considered to be not authenticated, all
+    # of the tests for authentication have failed
+    return False
+
 def check_token(self, token, tokens_m = None, request = None):
     # in case the provided token is invalid or empty the method
     # return immediately in success (simple validation)
@@ -1472,6 +1520,7 @@ def check_token(self, token, tokens_m = None, request = None):
     # of parts to validate the complete chain of values against
     # the map of token parts (namespace validation)
     for token_p in token_l:
+        if not isinstance(tokens_m, dict): return False
         if "*" in tokens_m and tokens_m["*"] == True: return True
         if not token_p in tokens_m: return False
         tokens_m = tokens_m[token_p]
@@ -1501,7 +1550,7 @@ def check_tokens(self, tokens, tokens_m = None, request = None):
 
 def ensure_login(self, token = None, context = None, request = None):
     request = request or (self.request if self else None)
-    is_auth = "username" in request.session or hasattr(request, "tokens_p")
+    is_auth = check_user(self, request = request)
     if not is_auth: raise exceptions.AppierException(
         message = "User not authenticated",
         code = 403,
@@ -1516,7 +1565,7 @@ def ensure_login(self, token = None, context = None, request = None):
         context = context
     )
 
-def get_tokens_m(self, request = None, set = True):
+def get_tokens_m(self, request = None, set = None):
     """
     Retrieves the map of tokens from the current session so that
     they can be used for proper ACL validation.
@@ -1528,8 +1577,10 @@ def get_tokens_m(self, request = None, set = True):
     :param request: The request that is going to be used to access
     the session information, if any.
     :type set: bool
-    :param set: If the possible converted tokens list should be persisted
-    into the current session.
+    :param set: If the possibly converted tokens list should be persisted
+    into the current session, sparing some CPU cycles on next execution,
+    in case no value is provided a default value is applied taking into
+    account the current execution context.
     :rtype: Dictionary
     :return: The map of tokens to be used for ACL validation.
     """
@@ -1540,13 +1591,19 @@ def get_tokens_m(self, request = None, set = True):
     request = request or (self.request if self else None)
     if not request: return dict()
 
+    # verifies if the set flag is set and if that's not the case
+    # ensures proper default value taking into account if there's
+    # a token "provider method" defined or not
+    if set == None:
+        set = False if hasattr(request, "tokens_p") else True
+
     # tries to retrieve the "provider method "for the tokens under the
     # current request an in case it's not available used the default
     # one (simple session access)
     try:
         if hasattr(request, "tokens_p"): tokens_m = request.tokens_p()
         else: tokens_m = request.session.get("tokens", {})
-    except BaseException:
+    except Exception:
         return dict()
 
     # verifies if the resulting value is either a map or a sequence,
